Creazione di intervalli di indirizzi pubblici

È possibile creare un intervallo di indirizzi pubblici definendone la dimensione e, facoltativamente, specificando una VPC da associarvi in qualsiasi zona di disponibilità all'interno dell'account.BYOIP (IPv4) Beta Gli indirizzi possono essere assegnati da pool IP gestiti d IBM o da un CIDR personalizzato autorizzato, qualora si desideri utilizzare un proprio intervallo di indirizzi IP pubblicamente instradabili.

Se la VPC viene eliminata mentre è legata a un intervallo di indirizzi pubblici, l'intervallo di indirizzi continua a esistere e può essere legato successivamente a una VPC diversa in qualsiasi zona di disponibilità.

È possibile creare intervalli di indirizzi pubblici con la console, la CLI, l'API e Terraform.

Prima di iniziare

Assicuratevi di rivedere le considerazioni sulla pianificazione delle gamme di indirizzi pubblici.

Creazione di intervalli di indirizzi pubblici nella console

Per creare intervalli di indirizzi pubblici nella console IBM Cloud, procedere come segue:

  1. Dalla console IBM Cloud, seleziona l' icona Menu del menu di navigazione, quindi fai clic sull'icona Infrastruttura VPC > Rete > Intervalli di indirizzi pubblici. Viene visualizzata la pagina Gamme di indirizzi pubblici per VPC.

  2. Fare clic su Crea per accedere alla pagina di provisioning.

  3. Nella sezione "Posizione", indica la regione in cui desideri che venga creato l'intervallo di indirizzi pubblici.

  4. Nella sezione "Dettagli", inserisci le seguenti informazioni:

    • Dimensione: selezionare la dimensione (numero di indirizzi IP) dell'intervallo di indirizzi. È possibile scegliere tra 1, 2, 4, 8 o 16 IP da includere nel blocco.

      Dopo aver creato un intervallo di indirizzi pubblici, non è possibile modificarne le dimensioni.

    • Nome: (facoltativo): inserire un nome per l'intervallo di indirizzi pubblici, ad esempio my-public-address-range.

    • Gruppo di risorse: Selezionare un gruppo di risorse per l'intervallo di indirizzi pubblici.

      Dopo aver creato un intervallo di indirizzi pubblici, non è possibile modificare il gruppo di risorse.

    • Tag: (Facoltativo) Aggiungi dei tag per organizzare e trovare più facilmente le tue risorse. Puoi sempre aggiungere altri tag in un secondo momento. Per ulteriori informazioni, consulta la sezione “Utilizzo dei tag ”.BYOIP (IPv4) Beta

    • Fonte del sistema di diffusione sonora: selezionare una delle seguenti opzioni:

      • IBM CIDR: Scegliere tra i pool di indirizzi IP gestiti d IBM. Quindi, selezionare la dimensione (numero di indirizzi IP) dell'intervallo di indirizzi. È possibile scegliere tra 1, 2, 4, 8 o 16 IP da includere nel blocco.

        Dopo aver creato un intervallo di indirizzi pubblici, non è possibile modificarne le dimensioni.

      • CIDR autorizzati personalizzati: dall'elenco dei CIDR autorizzati, selezionare il CIDR autorizzato personalizzato dal quale si desidera assegnare gli indirizzi. I blocchi CIDR disponibili sono limitati agli intervalli validi e non assegnati all'interno del CIDR personalizzato autorizzato selezionato.

        Quando si seleziona un CIDR personalizzato autorizzato, si assegnano indirizzi provenienti dal proprio intervallo IP anziché dai pool gestiti d IBM. Se nel menu non sono presenti CIDR autorizzati, è possibile inserire indirizzi IP provenienti da un CIDR autorizzato. Il nuovo CIDR è immediatamente disponibile per la selezione.

        Per ulteriori informazioni, consultare la sezione " Configurazione di un CIDR autorizzato personalizzato ".

      Per i CIDR autorizzati a livello di zona, sono disponibili solo i CIDR associati alla zona selezionata.

  5. (Facoltativo) Se desideri associare il tuo intervallo di indirizzi pubblici a una VPC esistente, imposta l'interruttore "Bind" su "On". Quindi, selezionare la VPC e la zona di disponibilità a cui ci si vuole associare.

    È possibile associare un intervallo di indirizzi pubblici a qualsiasi VPC in una singola zona di disponibilità già esistente nel proprio account. È inoltre possibile associare l'intervallo di indirizzi a una VPC in un secondo momento. Per ulteriori informazioni, vedere Binding di un intervallo di indirizzi pubblici.

  6. Fai clic su Crea. Si richiede l'utilizzo dell'intervallo di indirizzi pubblici.

Nella pagina "Intervalli di indirizzi pubblici per VPC", il tuo intervallo di indirizzi appare nella tabella. Ci vogliono alcuni minuti prima che lo stato dell'intervallo di indirizzi pubblici passi da Updating a Stable. Quando si trova nello stato “ Stable ”, l’intervallo di indirizzi è pronto per l’uso.

Creazione di intervalli di indirizzi pubblici dalla CLI

Per creare intervalli di indirizzi pubblici dalla riga di comando, procedere come segue:

  1. Configurare l'ambiente CLI.

  2. Accedere all'ambiente CLI. Dopo aver inserito la password, il sistema chiede quale account e quale regione si desidera utilizzare:

    ibmcloud login --sso
    
  3. Esegui il seguente comando:

    ibmcloud is public-address-range-create --ipv4-address-count IPV4_ADDRESS_COUNT [--name NAME] [--vpc VPC --zone ZONE] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

    BYOIP (IPv4) Beta

    ibmcloud is public-address-range-create (--ipv4-address-count IPV4_ADDRESS_COUNT | --cidr CIDR) [--name NAME] [--vpc VPC --zone ZONE] [--resource-group-id RESOURCE_GROUP_ID | --resource-group-name RESOURCE_GROUP_NAME] [--output JSON] [-q, --quiet]
    

    Dove:

    --ipv4-address-count
    Il numero totale di indirizzi IPv4 pubblici richiesti. Deve essere una potenza di 2.BYOIP (IPv4) Beta Si esclude a vicenda con --cidr.

    BYOIP (IPv4) Beta --cidr : L'intervallo di indirizzi IPv4 per questo sistema di diffusione sonora, espresso in formato CIDR. Deve trattarsi di un blocco non assegnato all'interno di un CIDR personalizzato autorizzato nel tuo account. Si esclude a vicenda con --ipv4-address-count.

    --name
    Un nome per l'intervallo di indirizzi pubblici. I nomi che iniziano con ibm- sono riservati alle risorse gestite dal provider e non sono consentiti.
    --vpc
    Il VPC a cui associare questo intervallo di indirizzi pubblici. Richiede " --zone".
    --zone
    La zona in cui si trova questo intervallo di indirizzi di diffusione sonora. Richiede " --vpc".
    --resource-group-id
    ID del gruppo di risorse. Si esclude a vicenda con --resource-group-name.
    --resource-group-name
    Nome del gruppo di risorse. Si esclude a vicenda con --resource-group-id.
    --output
    Per quanto riguarda il formato di output, è supportato solo JSON. Uno di: JSON.
    -q, --quiet
    Sopprimi l'output dettagliato.

Esempi di comando

Creare un intervallo di indirizzi pubblici denominato public-address-range-1 con un numero di indirizzi pari a 8:

ibmcloud is public-address-range-create --name public-address-range-1 --ipv4-address-count 8

Creare un intervallo di indirizzi pubblico denominato “ public-address-range-2 ” con 4 indirizzi e un gruppo di risorse denominato “ Default ”:

ibmcloud is public-address-range-create --name public-address-range-2 --ipv4-address-count 4 --resource-group-name Default

Creare un intervallo di indirizzi pubblici denominato public-address-range-3 con un numero di indirizzi pari a 8, legato alla VPC cli-test-vpc nella zona us-south-1 con ID gruppo di risorse 72b27b5c-f4b0-48bb-b954-5becc7c1dcb3:

ibmcloud is public-address-range-create --name public-address-range-3 --ipv4-address-count 8 --vpc cli-test-vpc --zone us-south-1 --resource-group-id 72b27b5c-f4b0-48bb-b954-5becc7c1dcb3

BYOIP (IPv4) BetaCreare un intervallo di indirizzi pubblici a partire da un CIDR personalizzato autorizzato, associato a una VPC e a una zona:

ibmcloud is public-address-range-create --name public-address-range-3 --cidr 46.16.186.112/28 --vpc cli-test-vpc --zone us-south-2 --resource-group-name Default

Creare un intervallo di indirizzi pubblici non vincolato a partire da un CIDR personalizzato autorizzato:

ibmcloud is public-address-range-create --name public-address-range-4 --cidr 46.16.186.128/28 --resource-group-name Default

Creare intervalli di indirizzi pubblici con l'API

Prima di iniziare, configura il tuo ambiente API.

Selezionare una delle seguenti opzioni:

  • Creare un intervallo di indirizzi pubblici a partire dagli IP gestiti d IBM, associati a una VPC:

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "ipv4_address_count": 8,
          "name": "my-public-address-range",
          "target": {
             "vpc": {
                "id": "r006-4727d842-f94f-4a2d-824a-9bc9b02c523b"
             },
             "zone": {
                "name": "us-south-1"
             }
          }
       }'
    
  • Creare un intervallo di indirizzi pubblici non associati dagli IP gestiti d IBM:

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "ipv4_address_count": 8,
          "name": "my-public-address-range"
       }'
    

BYOIP (IPv4) Beta

  • Crea un intervallo di indirizzi pubblici a partire da un CIDR autorizzato personalizzato (richiede un'azione IAM di tipo " is.public-address-range.authorized-cidr.operate " sul CIDR autorizzato):

    curl -sX POST \
    "$vpc_api_endpoint/v1/public_address_ranges?version=$api_version&generation=2" \
    -H "Authorization: Bearer $iam_token" \
    -H "Content-Type: application/json" \
    -d '{
          "cidr": "192.168.3.192/28",
          "name": "my-par-from-cidr"
       }'
    

Se è necessario modificare le dimensioni dell'intervallo di indirizzi o del gruppo di risorse, è necessario eliminare e ricreare l'intervallo di indirizzi.

Passi successivi